#!/usr/bin/env python3

import sys
import os
import string
import numpy as np
import h5py
import plotext as plt


def print_usage():
    print(f"Usage: '{os.path.basename(__file__)} <ngauge output file> <counter ID> [<counter ID> ...]'", file=sys.stderr)


def fail():
    print_usage()
    sys.exit(1)


def list_datasets(file):
    with h5py.File(file,'r') as f:
        print(f"The following counters are available in file {os.path.basename(file)}:", file=sys.stderr)
        for k in f.keys():
            print(hex(int(k)))


def display(file, counters):
    with h5py.File(file,'r') as f:
        for c in counters:
            dset = f[c]

        for c in counters:
            dset = f[c]
            name = dset.attrs["name"]
            time = (dset[1:, 0] - dset[1, 0]) * 1e-9
            # TODO: proper normalization - TBD if from the metadata or not
            if "PCI" not in name:
                normalizer = (np.diff(dset[:, 0] - dset[0, 0])) * 1e-9
                data = dset[1:, 2] / normalizer
            else:
                data = dset[1:, 2]

            plt.scatter(time, data)
            plt.title(name)
            plt.xlabel("Approx. time (s)")
            plt.plotsize(100, 30)
            plt.show()
            plt.clf()
            print()


if __name__ == '__main__':
    if len(sys.argv) < 3:
        fail()

    if not os.path.isfile(sys.argv[1]):
        fail()

    counters = []
    for cnt in sys.argv[2:]:
        if cnt.isdigit():
            counters.append(cnt)
        elif cnt.startswith("0x") and all(c in string.hexdigits for c in cnt[2:]):
            counters.append(str(int(cnt, 16)))
        else:
            fail()

    try:
        display(sys.argv[1], counters)
    except KeyError:
        list_datasets(sys.argv[1])
        sys.exit(1)
